package com.ztmap.project.zhny.strategy.service.impl;

import java.util.List;
import java.util.Map;

import com.ztmap.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ztmap.project.zhny.strategy.mapper.TStrategyMapper;
import com.ztmap.project.zhny.strategy.domain.TStrategy;
import com.ztmap.project.zhny.strategy.service.ITStrategyService;
import com.ztmap.common.utils.text.Convert;

/**
 * 策略管理Service业务层处理
 * 
 * @author ztmap
 * @date 2023-10-11
 */
@Service
public class TStrategyServiceImpl implements ITStrategyService 
{
    @Autowired
    private TStrategyMapper tStrategyMapper;

    /**
     * 查询策略管理
     * 
     * @param id 策略管理ID
     * @return 策略管理
     */
    @Override
    public TStrategy selectTStrategyById(Long id)
    {
        return tStrategyMapper.selectTStrategyById(id);
    }

    /**
     * 查询策略管理列表
     * 
     * @param tStrategy 策略管理
     * @return 策略管理
     */
    @Override
    public List<TStrategy> selectTStrategyList(TStrategy tStrategy)
    {
        return tStrategyMapper.selectTStrategyList(tStrategy);
    }

    /**
     * 新增策略管理
     * 
     * @param tStrategy 策略管理
     * @return 结果
     */
    @Override
    public int insertTStrategy(TStrategy tStrategy)
    {
        return tStrategyMapper.insertTStrategy(tStrategy);
    }

    /**
     * 修改策略管理
     * 
     * @param tStrategy 策略管理
     * @return 结果
     */
    @Override
    public int updateTStrategy(TStrategy tStrategy)
    {
        return tStrategyMapper.updateTStrategy(tStrategy);
    }

    /**
     * 删除策略管理对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTStrategyByIds(String ids)
    {
        return tStrategyMapper.deleteTStrategyByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除策略管理信息
     * 
     * @param id 策略管理ID
     * @return 结果
     */
    @Override
    public int deleteTStrategyById(Long id)
    {
        return tStrategyMapper.deleteTStrategyById(id);
    }

    @Override
    public List<TStrategy> getStrategyList(Map<String, Object> params) {
        return tStrategyMapper.getStrategyList(params);
    }
}
